@@ -43,7 +43,6 @@
 
 #include <Lum/ButtonRow.h>
 #include <Lum/Dialog.h>
-#include <Lum/Space.h>
 #include <Lum/Table.h>
 #include <Lum/Text.h>
 
@@ -77,7 +76,7 @@ public:
   : rateAction(new Lum::Model::Action()),
     uploadAction(new Lum::Model::Action()),
     aboutAction(new Lum::Model::Action()),
-    packages(new Lum::Model::ListTable(2)),
+    packages(new Lum::Model::ListTable()),
     selection(new Lum::Model::SingleLineSelection()),
     packageListTask(packages)
   {
@@ -100,14 +99,12 @@ public:
 
   void PreInit()
   {
-    Lum::Button           *button;
     Lum::Panel            *hpanel,*vpanel;
     Lum::Table            *table;
     Lum::Text             *text;
     Lum::Model::HeaderRef headerModel;
 
-    hpanel=new Lum::HPanel();
-    hpanel->SetFlex(true,true);
+    hpanel=Lum::HPanel::Create(true,true);
 
     headerModel=new Lum::Model::HeaderImpl();
     headerModel->AddColumn(L"Package",Lum::Base::Size::stdCharWidth,10,true);
@@ -125,24 +122,13 @@ public:
     //table->GetTableView()->SetAutoHSize(true);
     hpanel->Add(table);
 
-    hpanel->Add(new Lum::HSpace());
+    hpanel->AddSpace();
 
-    vpanel=new Lum::VPanel();
-    vpanel->SetFlex(false,true);
-
-    button=new Lum::Button(L"_Rate");
-    button->SetFlex(true,false);
-    button->SetModel(rateAction);
-    vpanel->Add(button);
-
-    vpanel->Add(new Lum::VSpace());
-
-    button=new Lum::Button(L"_Upload rates");
-    button->SetFlex(true,false);
-    button->SetModel(uploadAction);
-    vpanel->Add(button);
-
-    vpanel->Add(new Lum::VSpace(true));
+    vpanel=Lum::VPanel::Create(false,true);
+    vpanel->Add(Lum::Button::Create(L"_Rate",rateAction,true,false));
+    vpanel->AddSpace();
+    vpanel->Add(Lum::Button::Create(L"_Upload rates",uploadAction,true,false));
+    vpanel->AddSpace(true);
 
     text=new Lum::Text();
     text->SetFlex(true,false);
